import 'package:bluebubbles/helpers/hex_color.dart';
import 'package:bluebubbles/layouts/stateful_wrapper.dart';
import 'package:bluebubbles/managers/settings_manager.dart';
import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'package:battery_optimization/battery_optimization.dart';
import 'package:get/get.dart';
import 'package:shimmer/shimmer.dart';

class BatteryOptimizationPage extends StatelessWidget {
  const BatteryOptimizationPage({Key? key, required this.controller}) : super(key: key);
  final PageController controller;

  @override
  Widget build(BuildContext context) {
    return StatefulWrapper(
        onInit: () {
          // If battery optimizations are already disabled, go to the next page
          BatteryOptimization.isIgnoringBatteryOptimizations().then((isDisabled) {
            if (isDisabled!) {
              controller.nextPage(
                duration: Duration(milliseconds: 300),
                curve: Curves.easeInOut,
              );
            }
          });
        },
        child: AnnotatedRegion<SystemUiOverlayStyle>(
          value: SystemUiOverlayStyle(
            systemNavigationBarColor: SettingsManager().settings.immersiveMode.value ? Colors.transparent : Theme.of(context).backgroundColor, // navigation bar color
            systemNavigationBarIconBrightness: Theme.of(context).backgroundColor.computeLuminance() > 0.5 ? Brightness.dark : Brightness.light,
            statusBarColor: Colors.transparent, // status bar color
          ),
          child: Scaffold(
            backgroundColor: Theme.of(context).backgroundColor,
            body: LayoutBuilder(
              builder: (context, size) {
                return SingleChildScrollView(
                  child: ConstrainedBox(
                    constraints: BoxConstraints(
                      minHeight: size.maxHeight,
                    ),
                    child: Padding(
                      padding: const EdgeInsets.only(top: 80.0, left: 20.0, right: 20.0, bottom: 40.0),
                      child: Column(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: <Widget>[
                          Column(
                            children: [
                              Padding(
                                padding: const EdgeInsets.all(8.0),
                                child: Align(
                                  alignment: Alignment.centerLeft,
                                  child: Container(
                                    width: context.width * 2 / 3,
                                    child: Text(
                                        "Battery Optimization",
                                        style: Theme.of(context).textTheme.bodyText1!.apply(
                                          fontSizeFactor: 2.5,
                                          fontWeightDelta: 2,
                                        ).copyWith(height: 1.5)
                                    ),
                                  ),
                                ),
                              ),
                              Padding(
                                padding: const EdgeInsets.all(8.0),
                                child: Align(
                                  alignment: Alignment.centerLeft,
                                  child: Text(
                                      "We recommend disabling battery optimization for BlueBubbles to ensure you receive all your notifications.",
                                      style: Theme.of(context).textTheme.bodyText1!.apply(
                                        fontSizeFactor: 1.1,
                                        color: Colors.grey,
                                      ).copyWith(height: 2)
                                  ),
                                ),
                              ),
                              Padding(
                                padding: const EdgeInsets.symmetric(horizontal: 8.0, vertical: 13),
                                child: Align(
                                  alignment: Alignment.centerLeft,
                                  child: Container(
                                    decoration: BoxDecoration(
                                      borderRadius: BorderRadius.circular(25),
                                      gradient: LinearGradient(
                                        begin: AlignmentDirectional.topStart,
                                        colors: [HexColor('2772C3'), HexColor('5CA7F8').darkenPercent(5)],
                                      ),
                                    ),
                                    height: 40,
                                    child: ElevatedButton(
                                      style: ButtonStyle(
                                        shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                                          RoundedRectangleBorder(
                                            borderRadius: BorderRadius.circular(20.0),
                                          ),
                                        ),
                                        backgroundColor: MaterialStateProperty.all(Colors.transparent),
                                        shadowColor: MaterialStateProperty.all(Colors.transparent),
                                        maximumSize: MaterialStateProperty.all(Size(200, 36)),
                                      ),
                                      onPressed: () async {
                                        BatteryOptimization.openBatteryOptimizationSettings();
                                      },
                                      child: Shimmer.fromColors(
                                        baseColor: Colors.white70,
                                        highlightColor: Colors.white,
                                        child: Row(
                                          mainAxisSize: MainAxisSize.min,
                                          children: [
                                            Text(
                                              "Go to settings",
                                              style: Theme.of(context).textTheme.bodyText1!.apply(fontSizeFactor: 1.1)
                                            ),
                                            SizedBox(width: 10),
                                            Icon(Icons.arrow_forward, color: Colors.white, size: 20),
                                          ],
                                        ),
                                      ),
                                    ),
                                  ),
                                ),
                              ),
                            ],
                          ),
                          Row(
                            mainAxisAlignment: MainAxisAlignment.spaceBetween,
                            children: [
                              Container(
                                decoration: BoxDecoration(
                                  borderRadius: BorderRadius.circular(25),
                                  gradient: LinearGradient(
                                    begin: AlignmentDirectional.topStart,
                                    colors: [HexColor('2772C3'), HexColor('5CA7F8').darkenPercent(5)],
                                  ),
                                ),
                                height: 40,
                                padding: EdgeInsets.all(2),
                                child: ElevatedButton(
                                  style: ButtonStyle(
                                    shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                                      RoundedRectangleBorder(
                                        borderRadius: BorderRadius.circular(20.0),
                                      ),
                                    ),
                                    backgroundColor: MaterialStateProperty.all(Theme.of(context).backgroundColor),
                                    shadowColor: MaterialStateProperty.all(Theme.of(context).backgroundColor),
                                    maximumSize: MaterialStateProperty.all(Size(200, 36)),
                                  ),
                                  onPressed: () async {
                                    controller.previousPage(
                                      duration: Duration(milliseconds: 300),
                                      curve: Curves.easeInOut,
                                    );
                                  },
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: [
                                      Icon(Icons.arrow_back, color: Colors.white, size: 20),
                                      SizedBox(width: 10),
                                      Text(
                                          "Back",
                                          style: Theme.of(context).textTheme.bodyText1!.apply(fontSizeFactor: 1.1)
                                      ),
                                    ],
                                  ),
                                ),
                              ),
                              Container(
                                decoration: BoxDecoration(
                                  borderRadius: BorderRadius.circular(25),
                                  gradient: LinearGradient(
                                    begin: AlignmentDirectional.topStart,
                                    colors: [HexColor('2772C3'), HexColor('5CA7F8').darkenPercent(5)],
                                  ),
                                ),
                                height: 40,
                                child: ElevatedButton(
                                  style: ButtonStyle(
                                    shape: MaterialStateProperty.all<RoundedRectangleBorder>(
                                      RoundedRectangleBorder(
                                        borderRadius: BorderRadius.circular(20.0),
                                      ),
                                    ),
                                    backgroundColor: MaterialStateProperty.all(Colors.transparent),
                                    shadowColor: MaterialStateProperty.all(Colors.transparent),
                                    maximumSize: MaterialStateProperty.all(Size(200, 36)),
                                  ),
                                  onPressed: () async {
                                    controller.nextPage(
                                      duration: Duration(milliseconds: 300),
                                      curve: Curves.easeInOut,
                                    );
                                  },
                                  child: Row(
                                    mainAxisSize: MainAxisSize.min,
                                    children: [
                                      Text(
                                          "Next",
                                          style: Theme.of(context).textTheme.bodyText1!.apply(fontSizeFactor: 1.1)
                                      ),
                                      SizedBox(width: 10),
                                      Icon(Icons.arrow_forward, color: Colors.white, size: 20),
                                    ],
                                  ),
                                ),
                              ),
                            ],
                          ),
                        ],
                      ),
                    ),
                  ),
                );
              }
            ),
          ),
        ));
  }
}
